pub struct AtcScopePackage {
pub facilities: Vec<AtcFacility>,
pub maps: HashMap<String, AtcMap>,
pub symbols: HashMap<String, AtcMapSymbol>,
pub display_types: HashMap<String, AtcDisplayType>,
}Fields
facilities: Vec<AtcFacility>maps: HashMap<String, AtcMap>symbols: HashMap<String, AtcMapSymbol>display_types: HashMap<String, AtcDisplayType>Implementations
Sourceimpl AtcScopePackage
impl AtcScopePackage
Sourcepub fn export_to_gzip(
&self,
file_name: impl AsRef<Path>,
maps_dir: impl AsRef<Path>,
) -> Result<()>
pub fn export_to_gzip( &self, file_name: impl AsRef<Path>, maps_dir: impl AsRef<Path>, ) -> Result<()>
Exports the entire ATC Scope Package to a file.
File is tarred and gzipped.
All video maps are externalized from the main JSON file to allow lazy loading. These video maps are GeoJSON FeatureCollections
Format is as follows:
<name>.atcpkgScopePackage.jsonmaps<videomap>.geojson- …
pub fn import_from_gzip( file_name: impl AsRef<Path>, out_dir: impl AsRef<Path>, ) -> Result<Self>
Sourcepub fn try_load_map_data(
&mut self,
map_id: &str,
maps_dir: impl AsRef<Path>,
) -> Result<Option<&AtcMap>>
pub fn try_load_map_data( &mut self, map_id: &str, maps_dir: impl AsRef<Path>, ) -> Result<Option<&AtcMap>>
Attempts to lazy load a map.
If the map is embedded it will return immediately, otherwise it will load the map from the JSON file.
The map in this package will be replaced with the embedded one for performance.